pack_ptr_len

Function pack_ptr_len 

pub fn pack_ptr_len(ptr: i32, len: i32) -> i64
Pack a pointer and length into a single i64 value

This is the standard way to return two values from a Wasm function since wasm32-unknown-unknown doesn’t support multi-value returns.