Memory utilities for Wasm plugin development
Platform
These functions are designed for WASM32 targets only.
Pointer values are represented as i32, which is correct for WASM32’s
32-bit linear memory address space. Do not use on 64-bit native targets.
Enums
- Deserialize
Error - Error type for deserialization failures
Functions
- deserialize_
from_ ⚠ptr - Deserialize data from a raw pointer and length
- pack_
ptr_ len - Pack a pointer and length into a single i64 value
- plugin_
alloc - Allocate memory in the Wasm linear memory
- plugin_
dealloc - Deallocate memory in the Wasm linear memory
- serialize_
and_ return - Serialize data and return it as an allocated buffer